<?php
	/**
	 * This is a quick-and-dirty draft QPanel object to do Create, Edit, and Delete functionality
	 * of the Timetrack class.  It uses the code-generated
	 * TimetrackMetaControl class, which has meta-methods to help with
	 * easily creating/defining controls to modify the fields of a Timetrack columns.
	 *
	 * Any display customizations and presentation-tier logic can be implemented
	 * here by overriding existing or implementing new methods, properties and variables.
	 *
	 * NOTE: This file is overwritten on any code regenerations.  If you want to make
	 * permanent changes, it is STRONGLY RECOMMENDED to move both timetrack_edit.php AND
	 * timetrack_edit.tpl.php out of this Form Drafts directory.
	 *
	 * @package My QCubed Application
	 * @subpackage Drafts
	 */
	class TimetrackEditPanel extends QPanel {
		// Local instance of the TimetrackMetaControl
		/**
		 * @var TimetrackMetaControl
		 */
		protected $mctTimetrack;

		// Controls for Timetrack's Data Fields
		public $lblId;
		public $lstUserObject;
		public $lstProjectObject;
		public $calDate;
		public $calStartTime;
		public $calEndTime;

		// Other ListBoxes (if applicable) via Unique ReverseReferences and ManyToMany References

		// Other Controls
		/**
		 * @var QButton Save
		 */
		public $btnSave;
		/**
		 * @var QButton Delete
		 */
		public $btnDelete;
		/**
		 * @var QButton Cancel
		 */
		public $btnCancel;

		// Callback
		protected $strClosePanelMethod;

		public function __construct($objParentObject, $strClosePanelMethod, $intId = null, $strControlId = null) {
			// Call the Parent
			try {
				parent::__construct($objParentObject, $strControlId);
			} catch (QCallerException $objExc) {
				$objExc->IncrementOffset();
				throw $objExc;
			}

			// Setup Callback and Template
			// modification  by magia 2012 as suggested in qcubed-quick-start-guide_v210_Chapt_05 step 2
			$this->strTemplate = './TimetrackEditPanel.tpl.php';
			$this->strClosePanelMethod = $strClosePanelMethod;

			// Construct the TimetrackMetaControl
			// MAKE SURE we specify "$this" as the MetaControl's (and thus all subsequent controls') parent
			$this->mctTimetrack = TimetrackMetaControl::Create($this, $intId);

			// Call MetaControl's methods to create qcontrols based on Timetrack's data fields
			$this->lblId = $this->mctTimetrack->lblId_Create();
			$this->lstUserObject = $this->mctTimetrack->lstUserObject_Create();
			$this->lstProjectObject = $this->mctTimetrack->lstProjectObject_Create();
			$this->calDate = $this->mctTimetrack->calDate_Create();
			$this->calStartTime = $this->mctTimetrack->calStartTime_Create();
			$this->calEndTime = $this->mctTimetrack->calEndTime_Create();

			// Create Buttons and Actions on this Form
			$this->btnSave = new QButton($this);
			$this->btnSave->Text = QApplication::Translate('Save');
			$this->btnSave->AddAction(new QClickEvent(), new QAjaxControlAction($this, 'btnSave_Click'));
			$this->btnSave->CausesValidation = $this;

			$this->btnCancel = new QButton($this);
			$this->btnCancel->Text = QApplication::Translate('Cancel');
			$this->btnCancel->AddAction(new QClickEvent(), new QAjaxControlAction($this, 'btnCancel_Click'));

			$this->btnDelete = new QButton($this);
			$this->btnDelete->Text = QApplication::Translate('Delete');
			$this->btnDelete->AddAction(new QClickEvent(), new QConfirmAction(sprintf(QApplication::Translate('Are you SURE you want to DELETE this %s?'),  QApplication::Translate('Timetrack'))));
			$this->btnDelete->AddAction(new QClickEvent(), new QAjaxControlAction($this, 'btnDelete_Click'));
			$this->btnDelete->Visible = $this->mctTimetrack->EditMode;
		}

		// Control AjaxAction Event Handlers
		public function btnSave_Click($strFormId, $strControlId, $strParameter) {
			// Delegate "Save" processing to the TimetrackMetaControl
			$this->mctTimetrack->SaveTimetrack();
			$this->CloseSelf(true);
		}

		public function btnDelete_Click($strFormId, $strControlId, $strParameter) {
			// Delegate "Delete" processing to the TimetrackMetaControl
			$this->mctTimetrack->DeleteTimetrack();
			$this->CloseSelf(true);
		}

		public function btnCancel_Click($strFormId, $strControlId, $strParameter) {
			$this->CloseSelf(false);
		}

// modification  by magia 2012 as suggested in qcubed-quick-start-guide_v210_Chapt_05 panel validation
		public function Validate() {
			if ($this->calStartTime->DateTime > $this->calEndTime->DateTime){ 
				QApplication::DisplayAlert("Start time must be smaller then endtime");
				$this->calStartTime->Focus();
				return false;
			}
			return true;
		}


		// Close Myself and Call ClosePanelMethod Callback
		protected function CloseSelf($blnChangesMade) {
			$strMethod = $this->strClosePanelMethod;
			$this->objForm->$strMethod($blnChangesMade);
		}

		
	}
?>