<?php
	/**
	 * This is a quick-and-dirty draft QPanel object to do Create, Edit, and Delete functionality
	 * of the Login class.  It uses the code-generated
	 * LoginMetaControl class, which has meta-methods to help with
	 * easily creating/defining controls to modify the fields of a Login columns.
	 *
	 * Any display customizations and presentation-tier logic can be implemented
	 * here by overriding existing or implementing new methods, properties and variables.
	 *
	 * NOTE: This file is overwritten on any code regenerations.  If you want to make
	 * permanent changes, it is STRONGLY RECOMMENDED to move both login_edit.php AND
	 * login_edit.tpl.php out of this Form Drafts directory.
	 *
	 * @package My QCubed Application
	 * @subpackage Drafts
	 */
	class LoginEditPanel extends QPanel {
		// Local instance of the LoginMetaControl
		/**
		 * @var LoginMetaControl
		 */
		protected $mctLogin;

		// Controls for Login's Data Fields
		/** @var QLabel  */
		public $lblId;
		/** @var QListBox  */
		public $lstPerson;
		/** @var QTextBox  */
		public $txtUsername;
		/** @var QTextBox  */
		public $txtPassword;
		/** @var QIntegerTextBox  */
		public $txtIsEnabled;

		// Other ListBoxes (if applicable) via Unique ReverseReferences and ManyToMany References

		// Other Controls
		/**
		 * @var QButton Save
		 */
		public $btnSave;
		/**
		 * @var QButton Delete
		 */
		public $btnDelete;
		/**
		 * @var QButton Cancel
		 */
		public $btnCancel;

		// Callback
		protected $strClosePanelMethod;

		public function __construct($objParentObject, $strClosePanelMethod, $intId = null, $strControlId = null) {
			// Call the Parent
			try {
				parent::__construct($objParentObject, $strControlId);
			} catch (QCallerException $objExc) {
				$objExc->IncrementOffset();
				throw $objExc;
			}

			// Setup Callback and Template
			$this->strTemplate = __DOCROOT__ . __PANEL_DRAFTS__ . '/LoginEditPanel.tpl.php';
			$this->strClosePanelMethod = $strClosePanelMethod;

			// Construct the LoginMetaControl
			// MAKE SURE we specify "$this" as the MetaControl's (and thus all subsequent controls') parent
			$this->mctLogin = LoginMetaControl::Create($this, $intId);

			// Call MetaControl's methods to create qcontrols based on Login's data fields
			$this->lblId = $this->mctLogin->lblId_Create();
			$this->lstPerson = $this->mctLogin->lstPerson_Create();
			$this->txtUsername = $this->mctLogin->txtUsername_Create();
			$this->txtPassword = $this->mctLogin->txtPassword_Create();
			$this->txtIsEnabled = $this->mctLogin->txtIsEnabled_Create();

			// Create Buttons and Actions on this Form
			$this->btnSave = new QButton($this);
			$this->btnSave->Text = QApplication::Translate('Save');
			$this->btnSave->AddAction(new QClickEvent(), new QAjaxControlAction($this, 'btnSave_Click'));
			$this->btnSave->CausesValidation = $this;

			$this->btnCancel = new QButton($this);
			$this->btnCancel->Text = QApplication::Translate('Cancel');
			$this->btnCancel->AddAction(new QClickEvent(), new QAjaxControlAction($this, 'btnCancel_Click'));

			$this->btnDelete = new QButton($this);
			$this->btnDelete->Text = QApplication::Translate('Delete');
			$this->btnDelete->AddAction(new QClickEvent(), new QConfirmAction(sprintf(QApplication::Translate('Are you SURE you want to DELETE this %s?'),  QApplication::Translate('Login'))));
			$this->btnDelete->AddAction(new QClickEvent(), new QAjaxControlAction($this, 'btnDelete_Click'));
			$this->btnDelete->Visible = $this->mctLogin->EditMode;
		}

		// Control AjaxAction Event Handlers
		public function btnSave_Click($strFormId, $strControlId, $strParameter) {
			// Delegate "Save" processing to the LoginMetaControl
			$this->mctLogin->SaveLogin();
			$this->CloseSelf(true);
		}

		public function btnDelete_Click($strFormId, $strControlId, $strParameter) {
			// Delegate "Delete" processing to the LoginMetaControl
			$this->mctLogin->DeleteLogin();
			$this->CloseSelf(true);
		}

		public function btnCancel_Click($strFormId, $strControlId, $strParameter) {
			$this->CloseSelf(false);
		}

		// Close Myself and Call ClosePanelMethod Callback
		protected function CloseSelf($blnChangesMade) {
			$strMethod = $this->strClosePanelMethod;
			$this->objForm->$strMethod($blnChangesMade);
		}

			// Check for records that may violate Unique Clauses
	public function Validate() {
		$blnToReturn = true;
			if (($objLogin = Login::LoadByPersonId($this->lstPerson->SelectedValue)) && ($objLogin->Id != $this->mctLogin->Login->Id )){
				$blnToReturn = false;
				$this->lstPerson->Warning = QApplication::Translate("Already in Use");
			}
			if (($objLogin = Login::LoadByUsername($this->txtUsername->Text)) && ($objLogin->Id != $this->mctLogin->Login->Id )){
				$blnToReturn = false;
				$this->txtUsername->Warning = QApplication::Translate("Already in Use");
			}
		return $blnToReturn;
	}

	}
?>